@@ -1,9 +1,3 @@
-use 5.010;
-use strict;
-use warnings;
-
-package Foo::Bar;
-
 our $VERSION = '0.10';
 
 1;
@@ -26,10 +20,10 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2012. Ingy döt Net.
+Copyright 2012-2014. Ingy döt Net.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
 
